@@ -276,7 +276,7 @@ class Api:
             debug=debug
         )
     
-    def download(
+    def _download(
         self,
         url: str,
         path: str,
@@ -288,7 +288,8 @@ class Api:
         extra_headers: Optional[Dict[str, any]] = None,
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: Optional[bool] = None,
-        debug: Optional[bool] = None
+        debug: Optional[bool] = None,
+        timeout: Optional[float] = None
     ) -> List[bool]:
         return self._request.download(
             url,
@@ -300,11 +301,16 @@ class Api:
             sleep_s_between_failed_requests=sleep_s_between_failed_requests,
             extra_headers=extra_headers,
             extra_cookies=extra_cookies,
-            debug=debug
+            debug=debug,
+            timeout=timeout
         )
 
+    # kept for convenience
+    download = _download
+
+
     @classmethod
-    def download_cls(
+    def _download_cls(
         cls,
         url: str,
         path: str,
@@ -315,7 +321,8 @@ class Api:
         extra_headers: Optional[Dict[str, any]] = None,
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: Optional[bool] = None,
-        debug: Optional[bool] = None
+        debug: Optional[bool] = None,
+        timeout: Optional[float] = None
     ) -> List[bool]:
         return Api(default_headers=cls.default_headers(), extra_headers=cls.extra_headers()).download(
             url,
@@ -328,10 +335,15 @@ class Api:
             extra_headers=extra_headers,
             extra_cookies=extra_cookies,
             allow_redirects=allow_redirects,
-            debug=debug
+            debug=debug,
+            timeout=timeout
         )
 
-    def download_async(
+    # kept for convenience
+    download_cls = _download_cls
+
+
+    def _download_async(
         self,
         urls_paths: Optional[Dict[str, str]] = None,
         user_agent: Optional[Union[str, List[str]]] = None,
@@ -343,7 +355,8 @@ class Api:
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: Optional[bool] = None,
         debug: Optional[bool] = None,
-        max_concurent_processes: Optional[int] = None
+        max_concurent_processes: Optional[int] = None,
+        request_timeout: Optional[float] = None
     ) -> List[bool]:
         return self._request.download_async(
             urls_paths,
@@ -355,11 +368,16 @@ class Api:
             extra_headers=extra_headers,
             extra_cookies=extra_cookies,
             debug=debug,
-            max_concurent_processes=max_concurent_processes
+            max_concurent_processes=max_concurent_processes,
+            request_timeout=request_timeout
         )
 
+    # kept for convenience
+    download_async = _download_async
+
+
     @classmethod
-    def download_async_cls(
+    def _download_async_cls(
         cls,
         urls_paths: Optional[Dict[str, str]] = None,
         user_agent: Optional[Union[str, List[str]]] = None,
@@ -370,7 +388,8 @@ class Api:
         extra_cookies: Optional[Dict[str, str]] = None,
         allow_redirects: bool = True,
         debug: Optional[bool] = None,
-        max_concurent_processes: Optional[int] = None
+        max_concurent_processes: Optional[int] = None,
+        request_timeout: Optional[float] = None
     ) -> List[bool]:
         return Api(default_headers=cls.default_headers(), extra_headers=cls.extra_headers()).download_async(
             urls_paths,
@@ -383,8 +402,12 @@ class Api:
             extra_cookies=extra_cookies,
             allow_redirects=allow_redirects,
             debug=debug,
-            max_concurent_processes=max_concurent_processes
+            max_concurent_processes=max_concurent_processes,
+            request_timeout=request_timeout
         )
 
+    # kept for convenience
+    download_async_cls = _download_async_cls
+
 
 # ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
